#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Inspire by Conbagui tutorial found here: http://gimpnexuxtutorials.blogspot.com/2020/06/making-it-simple-text-tutorial.html

# author: Pocholo
# date: 6/12/20

# Comments directed to http://gimpchat.com

# Installation:
# This script should be placed in the user plugin folder

# Copyright (C)

#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by   
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.

#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.

# Change log
##7-27-2022
# version rel 2 omitted the text color
# Created control for the inner shadow (opacity, angle, distant, size)
# Made and alternative for user own text creation


from gimpfu import *
import os, time, sys
import gettext
t = gettext.translation("gimp20-python", gimp.locale_directory, fallback=True)
_ = t.ugettext

def color_carvedin_text_v2(customtext, font, shadow_opa, shadow_angle, shadow_dist, shadow_size, backcolor, 
                        color1, color2, color3, color4, color5, color6, color7, color8):
   
    #Initiates the temporary state
    pdb.gimp_context_push()
    pdb.gimp_context_set_defaults()

    #Create the text 	
    size = 300
    img = pdb.gimp_image_new(1, 1, RGB)
    pdb.gimp_context_set_foreground("Black")
    textLayer = pdb.gimp_text_fontname(img, None, 0, 0, customtext, 150,
                                   True, size, PIXELS, font)
    pdb.gimp_text_layer_set_justification(textLayer, 2)
    pdb.gimp_text_layer_set_letter_spacing(textLayer, 40)
    pdb.gimp_text_layer_set_line_spacing(textLayer, 0)
    img.resize(textLayer.width, textLayer.height, 0, 0)
    pdb.gimp_item_set_name(textLayer, "Text")
    pdb.gimp_layer_resize_to_image_size(textLayer)
    textLayer = pdb.gimp_image_get_layer_by_name(img, "Text")
    x = textLayer.offsets[0]
    y = textLayer.offsets[1]
    x = (img.width - textLayer.width) / 2
    y = (img.height - textLayer.height) / 2
    textLayer.set_offsets(x, y)
    pdb.gimp_layer_resize_to_image_size(textLayer)
        
    #Rename the text layer and move up
    pdb.gimp_item_set_name(textLayer, "Text")
    
    #Image process
    pdb.gimp_display_new(img)

    #Create layer color 1
    layer1 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Color 1", 100, LAYER_MODE_NORMAL)
    pdb.gimp_context_set_foreground(color1)
    pdb.gimp_image_insert_layer(img, layer1, None, 0)
    pdb.gimp_drawable_fill(layer1, FILL_TRANSPARENT)
    pdb.gimp_image_select_item(img, 2, textLayer)
    pdb.gimp_selection_grow(img, 5)
    pdb.plug_in_sel2path(img, textLayer)
    vectors = pdb.gimp_image_get_active_vectors(img)
    pdb.gimp_vectors_to_selection(vectors, 2, TRUE, FALSE, 0, 0)
    pdb.gimp_drawable_edit_fill(layer1, FILL_FOREGROUND)
        
    #Create layer color 2
    layer2 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Color 2", 100, LAYER_MODE_NORMAL)
    pdb.gimp_context_set_foreground(color2)
    pdb.gimp_image_insert_layer(img, layer2, None, 0)
    pdb.gimp_drawable_fill(layer2, FILL_TRANSPARENT)
    pdb.gimp_selection_grow(img, 5)
    pdb.plug_in_sel2path(img, textLayer)
    vectors = pdb.gimp_image_get_active_vectors(img)
    pdb.gimp_vectors_to_selection(vectors, 2, TRUE, FALSE, 0, 0)
    pdb.gimp_drawable_edit_fill(layer2, FILL_FOREGROUND)
        
    #Create layer color 3
    layer3 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Color 3", 100, LAYER_MODE_NORMAL)
    pdb.gimp_context_set_foreground(color3)
    pdb.gimp_image_insert_layer(img, layer3, None, 0)
    pdb.gimp_drawable_fill(layer3, FILL_TRANSPARENT)
    pdb.gimp_selection_grow(img, 5)
    pdb.plug_in_sel2path(img, layer3)
    vectors = pdb.gimp_image_get_active_vectors(img)
    pdb.gimp_vectors_to_selection(vectors, 2, TRUE, FALSE, 0, 0)
    pdb.gimp_drawable_edit_fill(layer3, FILL_FOREGROUND)
            
    #Create layer color 4
    layer4 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Color 4", 100, LAYER_MODE_NORMAL)
    pdb.gimp_context_set_foreground(color4)
    pdb.gimp_image_insert_layer(img, layer4, None, 0)
    pdb.gimp_drawable_fill(layer4, FILL_TRANSPARENT)
    pdb.gimp_selection_grow(img, 5)
    pdb.plug_in_sel2path(img, layer4)
    vectors = pdb.gimp_image_get_active_vectors(img)
    pdb.gimp_vectors_to_selection(vectors, 2, TRUE, FALSE, 0, 0)
    pdb.gimp_drawable_edit_fill(layer4, FILL_FOREGROUND)
        
    #Create layer color 5
    layer5 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Color 5", 100, LAYER_MODE_NORMAL)
    pdb.gimp_context_set_foreground(color5)
    pdb.gimp_image_insert_layer(img, layer5, None, 0)
    pdb.gimp_drawable_fill(layer5, FILL_TRANSPARENT)
    pdb.gimp_selection_grow(img, 5)
    pdb.plug_in_sel2path(img, layer5)
    vectors = pdb.gimp_image_get_active_vectors(img)
    pdb.gimp_vectors_to_selection(vectors, 2, TRUE, FALSE, 0, 0)
    pdb.gimp_drawable_edit_fill(layer5, FILL_FOREGROUND)
        
    #Create layer color 6
    layer6 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Color 6", 100, LAYER_MODE_NORMAL)
    pdb.gimp_context_set_foreground(color6)
    pdb.gimp_image_insert_layer(img, layer6, None, 0)
    pdb.gimp_drawable_fill(layer6, FILL_TRANSPARENT)
    pdb.gimp_selection_grow(img, 5)
    pdb.plug_in_sel2path(img, layer6)
    vectors = pdb.gimp_image_get_active_vectors(img)
    pdb.gimp_vectors_to_selection(vectors, 2, TRUE, FALSE, 0, 0)
    pdb.gimp_drawable_edit_fill(layer6, FILL_FOREGROUND)
        
    #Create layer color 7
    layer7 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Color 7", 100, LAYER_MODE_NORMAL)
    pdb.gimp_context_set_foreground(color7)
    pdb.gimp_image_insert_layer(img, layer7, None, 0)
    pdb.gimp_drawable_fill(layer7, FILL_TRANSPARENT)
    pdb.gimp_selection_grow(img, 5)
    pdb.plug_in_sel2path(img, layer7)
    vectors = pdb.gimp_image_get_active_vectors(img)
    pdb.gimp_vectors_to_selection(vectors, 2, TRUE, FALSE, 0, 0)
    pdb.gimp_drawable_edit_fill(layer7, FILL_FOREGROUND)

    #Create layer color 8
    layer8 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Color 8", 100, LAYER_MODE_NORMAL)
    pdb.gimp_context_set_foreground(color8)
    pdb.gimp_image_insert_layer(img, layer8, None, 0)
    pdb.gimp_drawable_fill(layer8, FILL_TRANSPARENT)
    pdb.gimp_selection_grow(img, 5)
    pdb.plug_in_sel2path(img, layer8)
    vectors = pdb.gimp_image_get_active_vectors(img)
    pdb.gimp_vectors_to_selection(vectors, 2, TRUE, FALSE, 0, 0)
    pdb.gimp_drawable_edit_fill(layer8, FILL_FOREGROUND)
    
    #Reverse layers order
    pdb.script_fu_reverse_layers(img, layer8)
    pdb.gimp_selection_none(img)

    #Clear the center of each color layer text
    pdb.gimp_image_set_active_layer(img, layer1)
    pdb.gimp_image_select_item(img, 2, layer1)

    #Layer 1
    pdb.gimp_image_set_active_layer(img, layer1)
    pdb.gimp_edit_clear(layer1)


    #Layer 2
    pdb.gimp_image_set_active_layer(img, layer2)
    pdb.gimp_edit_clear(layer2)

    #Layer 3
    pdb.gimp_image_set_active_layer(img, layer3)
    pdb.gimp_edit_clear(layer3)

    #Layer 4
    pdb.gimp_image_set_active_layer(img, layer4)
    pdb.gimp_edit_clear(layer4)

    #Layer 5
    pdb.gimp_image_set_active_layer(img, layer5)
    pdb.gimp_edit_clear(layer5)

    #Layer 6
    pdb.gimp_image_set_active_layer(img, layer6)
    pdb.gimp_edit_clear(layer6)

    #Layer 7
    pdb.gimp_image_set_active_layer(img, layer7)
    pdb.gimp_edit_clear(layer7)

    #Layer 8
    pdb.gimp_image_set_active_layer(img, layer8)
    pdb.gimp_edit_clear(layer8)


    pdb.gimp_image_lower_item_to_bottom(img, textLayer)
        
    whitelayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "White", 100, LAYER_MODE_OVERLAY)
    pdb.gimp_image_insert_layer(img, whitelayer, None, 9)
    pdb.gimp_drawable_fill(whitelayer, FILL_TRANSPARENT)
    pdb.gimp_drawable_edit_fill(whitelayer, FILL_WHITE)
    pdb.gimp_selection_none(img)
        
    #Create the inner shadow
    pdb.python_layer_fx_inner_shadow(img, textLayer, 
                                          (0, 0, 0),
                                                 shadow_opa,   #opacity
                                                  5,    #0 for Linear contour
                                                  0,    #noise
                                                  3,    #mode 3 for multiply
                                                  1,    #source 0 for center 1 for edge check this one
                                                  0,    #choke
                                                 shadow_size,   #size
                                       shadow_angle,   #offset-angle
                                                 shadow_dist,   #offset-distance
                                              FALSE)   #merge with layer
    
    pdb.gimp_item_set_visible(textLayer, FALSE)

    #Create background
    backLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Background", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, backLayer, None, 11)
    pdb.gimp_context_set_background(backcolor)
    pdb.gimp_drawable_fill(backLayer, FILL_BACKGROUND)
    pdb.plug_in_gmic_qt(img, backLayer, 1, 0, 
        "-v - -fx_scanlines 50,5,2,145,0,0,0,0")
                
    pdb.gimp_selection_none(img)

    pdb.gimp_item_set_visible(backLayer, TRUE)

    #Make active the bottom layer and done
    pdb.gimp_image_set_active_layer(img, backLayer)
    
    #Resets the previous user defaults
    pdb.gimp_context_pop()


def color_carvedin_text_alt(img, layer, flatten, shadow_opa, shadow_angle, shadow_dist, shadow_size, backcolor, 
                        color1, color2, color3, color4, color5, color6, color7, color8):
    
    #Initiates the temporary state
    pdb.gimp_context_push()
    pdb.gimp_context_set_defaults()
    
    #Start undo
    pdb.gimp_image_undo_group_start(img)
        
    #Make active background layer and rename it
    img.layers[-1]
    backLayer = img.layers[-1]
    pdb.gimp_image_set_active_layer(img, backLayer)
    pdb.gimp_context_set_background(backcolor)
    pdb.gimp_drawable_fill(backLayer, FILL_BACKGROUND)
    pdb.gimp_item_set_name(backLayer, "Background")
    
    #Apply scanline pattern
    pdb.plug_in_gmic_qt(img, backLayer, 1, 0, 
    "-v - -fx_scanlines 50,5,2,145,0,0,0,0")
    
    #Make the text active
    img.layers[0]
    textLayer = img.layers[0]
    textLayer = pdb.gimp_image_set_active_layer(img, textLayer)      
    if textLayer==False:
        pdb.gimp_message_set_handler(0)
        pdb.gimp_message("Need to create a Text")       
        gimp.quit()
        
	#Make active the text 
    textLayer = pdb.gimp_image_get_active_drawable(img)
    pdb.gimp_image_set_active_layer(img, textLayer)
    pdb.gimp_item_set_name(textLayer, "Text")
    text_layer = pdb.gimp_item_is_text_layer(textLayer)
    line_spacing = pdb.gimp_text_layer_get_line_spacing(textLayer)
    pdb.gimp_text_layer_set_letter_spacing(textLayer, 60)
    wh = pdb.gimp_drawable_width(textLayer)
    hh = pdb.gimp_drawable_height(textLayer)
    w = pdb.gimp_image_width(img)
    h = pdb.gimp_image_height(img)    
    factor = min (float(img.width) / textLayer.width, float(img.height) / textLayer.height)
    textLayer.scale(int(textLayer.width * factor-150), int(textLayer.height * factor-50))
    x = textLayer.offsets[0]
    y = textLayer.offsets[1]
    x = (img.width - textLayer.width) / 2
    y = (img.height - textLayer.height) / 2
    textLayer.set_offsets(x, y)
    pdb.gimp_layer_resize_to_image_size(textLayer)

	#Create layer color 1
    layer1 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Color 1", 100, LAYER_MODE_NORMAL)
    pdb.gimp_context_set_foreground(color1)
    pdb.gimp_image_insert_layer(img, layer1, None, 0)
    pdb.gimp_drawable_fill(layer1, FILL_TRANSPARENT)
    pdb.gimp_image_select_item(img, 2, textLayer)
    pdb.gimp_selection_grow(img, 5)
    pdb.plug_in_sel2path(img, textLayer)
    vectors = pdb.gimp_image_get_active_vectors(img)
    pdb.gimp_vectors_to_selection(vectors, 2, TRUE, FALSE, 0, 0)
    pdb.gimp_drawable_edit_fill(layer1, FILL_FOREGROUND)
        
    #Create layer color 2
    layer2 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Color 2", 100, LAYER_MODE_NORMAL)
    pdb.gimp_context_set_foreground(color2)
    pdb.gimp_image_insert_layer(img, layer2, None, 0)
    pdb.gimp_drawable_fill(layer2, FILL_TRANSPARENT)
    pdb.gimp_selection_grow(img, 5)
    pdb.plug_in_sel2path(img, textLayer)
    vectors = pdb.gimp_image_get_active_vectors(img)
    pdb.gimp_vectors_to_selection(vectors, 2, TRUE, FALSE, 0, 0)
    pdb.gimp_drawable_edit_fill(layer2, FILL_FOREGROUND)
    
    #Create layer color 3
    layer3 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Color 3", 100, LAYER_MODE_NORMAL)
    pdb.gimp_context_set_foreground(color3)
    pdb.gimp_image_insert_layer(img, layer3, None, 0)
    pdb.gimp_drawable_fill(layer3, FILL_TRANSPARENT)
    pdb.gimp_selection_grow(img, 5)
    pdb.plug_in_sel2path(img, layer3)
    vectors = pdb.gimp_image_get_active_vectors(img)
    pdb.gimp_vectors_to_selection(vectors, 2, TRUE, FALSE, 0, 0)
    pdb.gimp_drawable_edit_fill(layer3, FILL_FOREGROUND)
            
    #Create layer color 4
    layer4 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Color 4", 100, LAYER_MODE_NORMAL)
    pdb.gimp_context_set_foreground(color4)
    pdb.gimp_image_insert_layer(img, layer4, None, 0)
    pdb.gimp_drawable_fill(layer4, FILL_TRANSPARENT)
    pdb.gimp_selection_grow(img, 5)
    pdb.plug_in_sel2path(img, layer4)
    vectors = pdb.gimp_image_get_active_vectors(img)
    pdb.gimp_vectors_to_selection(vectors, 2, TRUE, FALSE, 0, 0)
    pdb.gimp_drawable_edit_fill(layer4, FILL_FOREGROUND)
        
    #Create layer color 5
    layer5 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Color 5", 100, LAYER_MODE_NORMAL)
    pdb.gimp_context_set_foreground(color5)
    pdb.gimp_image_insert_layer(img, layer5, None, 0)
    pdb.gimp_drawable_fill(layer5, FILL_TRANSPARENT)
    pdb.gimp_selection_grow(img, 5)
    pdb.plug_in_sel2path(img, layer5)
    vectors = pdb.gimp_image_get_active_vectors(img)
    pdb.gimp_vectors_to_selection(vectors, 2, TRUE, FALSE, 0, 0)
    pdb.gimp_drawable_edit_fill(layer5, FILL_FOREGROUND)
        
    #Create layer color 6
    layer6 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Color 6", 100, LAYER_MODE_NORMAL)
    pdb.gimp_context_set_foreground(color6)
    pdb.gimp_image_insert_layer(img, layer6, None, 0)
    pdb.gimp_drawable_fill(layer6, FILL_TRANSPARENT)
    pdb.gimp_selection_grow(img, 5)
    pdb.plug_in_sel2path(img, layer6)
    vectors = pdb.gimp_image_get_active_vectors(img)
    pdb.gimp_vectors_to_selection(vectors, 2, TRUE, FALSE, 0, 0)
    pdb.gimp_drawable_edit_fill(layer6, FILL_FOREGROUND)
        
    #Create layer color 7
    layer7 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Color 7", 100, LAYER_MODE_NORMAL)
    pdb.gimp_context_set_foreground(color7)
    pdb.gimp_image_insert_layer(img, layer7, None, 0)
    pdb.gimp_drawable_fill(layer7, FILL_TRANSPARENT)
    pdb.gimp_selection_grow(img, 5)
    pdb.plug_in_sel2path(img, layer7)
    vectors = pdb.gimp_image_get_active_vectors(img)
    pdb.gimp_vectors_to_selection(vectors, 2, TRUE, FALSE, 0, 0)
    pdb.gimp_drawable_edit_fill(layer7, FILL_FOREGROUND)

    #Create layer color 8
    layer8 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Color 8", 100, LAYER_MODE_NORMAL)
    pdb.gimp_context_set_foreground(color8)
    pdb.gimp_image_insert_layer(img, layer8, None, 0)
    pdb.gimp_drawable_fill(layer8, FILL_TRANSPARENT)
    pdb.gimp_selection_grow(img, 5)
    pdb.plug_in_sel2path(img, layer8)
    vectors = pdb.gimp_image_get_active_vectors(img)
    pdb.gimp_vectors_to_selection(vectors, 2, TRUE, FALSE, 0, 0)
    pdb.gimp_drawable_edit_fill(layer8, FILL_FOREGROUND)
    
    #Reverse layers order
    pdb.script_fu_reverse_layers(img, layer8)
    pdb.gimp_selection_none(img)
    
    #Create a selection on the text
    pdb.gimp_image_set_active_layer(img, layer1)
    pdb.gimp_image_select_item(img, 2, layer1)

    #Layer 1
    pdb.gimp_image_set_active_layer(img, layer1)
    pdb.gimp_edit_clear(layer1)

    #Layer 2
    pdb.gimp_image_set_active_layer(img, layer2)
    pdb.gimp_edit_clear(layer2)

    #Layer 3
    pdb.gimp_image_set_active_layer(img, layer3)
    pdb.gimp_edit_clear(layer3)

    #Layer 4
    pdb.gimp_image_set_active_layer(img, layer4)
    pdb.gimp_edit_clear(layer4)

    #Layer 5
    pdb.gimp_image_set_active_layer(img, layer5)
    pdb.gimp_edit_clear(layer5)

    #Layer 6
    pdb.gimp_image_set_active_layer(img, layer6)
    pdb.gimp_edit_clear(layer6)

    #Layer 7
    pdb.gimp_image_set_active_layer(img, layer7)
    pdb.gimp_edit_clear(layer7)

    #Layer 8
    pdb.gimp_image_set_active_layer(img, layer8)
    pdb.gimp_edit_clear(layer8)
    
    #Lower both top layers
    pdb.gimp_image_lower_item_to_bottom(img, textLayer)
    pdb.gimp_image_lower_item_to_bottom(img, backLayer)
    
    #Create the brighten layer    
    whitelayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "White", 100, LAYER_MODE_OVERLAY)
    pdb.gimp_image_insert_layer(img, whitelayer, None, 8)
    pdb.gimp_drawable_fill(whitelayer, FILL_TRANSPARENT)
    pdb.gimp_drawable_edit_fill(whitelayer, FILL_WHITE)
    pdb.gimp_selection_none(img)
        
    #Create the inner shadow
    pdb.python_layer_fx_inner_shadow(img, textLayer, 
                                          (0, 0, 0),
                                         shadow_opa,   #opacity
                                                  5,    #0 for Linear contour
                                                  0,    #noise
                                                  3,    #mode 3 for multiply
                                                  1,    #source 0 for center 1 for edge check this one
                                                  0,    #choke
                                        shadow_size,   #size
                                       shadow_angle,   #offset-angle
                                        shadow_dist,   #offset-distance
                                              FALSE)   #merge with layer
    
    #Make the text invisible
    pdb.gimp_item_set_visible(textLayer, FALSE)
   
    pdb.gimp_selection_none(img)
    
    #Make active the bottom layer and done
    pdb.gimp_image_set_active_layer(img, backLayer)
    
    #Merge visible image option
    if flatten:
	    image.merge_visible_layers(EXPAND_AS_NECESSARY)								
    pdb.gimp_displays_flush()			
 
    #Resets the previous user defaults
    pdb.gimp_context_pop()	
    
    #Undo group end
    pdb.gimp_image_undo_group_end(img)
    
register(
    "color_carvedin_text_alt",
    "Creates a carvedin text",
    "Creates a carvedin text",
    "Pocholo",
    "Pocholo",
    "2022",
    "Color carved in text",
    "",
    [
    (PF_IMAGE, "img", "Input image", None),    #current image
    (PF_DRAWABLE, "layer", "Input layer", None), #current layer
    (PF_BOOL,  "flatten", "Merge layers:", False),
    (PF_SPINNER, "shadow_opa", "Shadow Opacity:", 85.0, (0.0, 100.0, 0.1)),
    (PF_SPINNER, "shadow_angle", "Shadow Angle:", 120, (-180, 180, 1)),
    (PF_SPINNER, "shadow_dist", "Shadow Distant:", 21.0, (0.0, 40.0, 0.1)),
	(PF_SPINNER, "shadow_size", "Shadow Size:", 18, (0, 40, 1)),
    (PF_COLOR, "backcolor", "Background color", (22, 22, 22)),
    (PF_COLOR, "color1", "Create color 1", (128,0,128)),
    (PF_COLOR, "color2", "Create color 2", (255,165,0)),
	(PF_COLOR, "color3", "Create color 3", (0,255,0)),
	(PF_COLOR, "color4", "Create color 4", (0,255,255)),
	(PF_COLOR, "color5", "Create color 5", (255,0,255)),
	(PF_COLOR, "color6", "Create color 6", (0,0,255)),
	(PF_COLOR, "color7", "Create color 7", (255,255,0)),
	(PF_COLOR, "color8", "Create color 8", (255, 0, 0)),
    ],
    [],
    color_carvedin_text_alt, menu="<Image>/Filters/Alpha to Logo")	
	
register(
    "color_carvedin_text_v2",
    "Creates a carvedin text",
    "Creates a carvedin text",
    "Pocholo",
    "Pocholo",
    "2020",
    "Color carved in text V2",
    "",
    [
	(PF_STRING, "customtext", "Text string", 'AWE'),
    (PF_FONT, "font", "Font face", "Arial"),
    (PF_SPINNER, "shadow_opa", "Shadow Opacity:", 85.0, (0.0, 100.0, 0.1)),
    (PF_SPINNER, "shadow_angle", "Shadow Angle:", 120, (-180, 180, 1)),
    (PF_SPINNER, "shadow_dist", "Shadow Distant:", 21.0, (0.0, 40.0, 0.1)),
	(PF_SPINNER, "shadow_size", "Shadow Size:", 18, (0, 40, 1)),
    (PF_COLOR, "backcolor", "Background color", (22, 22, 22)),
    (PF_COLOR, "color1", "Create color 1", (128,0,128)),
    (PF_COLOR, "color2", "Create color 2", (255,165,0)),
	(PF_COLOR, "color3", "Create color 3", (0,255,0)),
	(PF_COLOR, "color4", "Create color 4", (0,255,255)),
	(PF_COLOR, "color5", "Create color 5", (255,0,255)),
	(PF_COLOR, "color6", "Create color 6", (0,0,255)),
	(PF_COLOR, "color7", "Create color 7", (255,255,0)),
	(PF_COLOR, "color8", "Create color 8", (255, 0, 0)),
    ],
    [],
    color_carvedin_text_v2, menu="<Image>/Pocholo's-Plugins/")
main()